@@ -1,31 +1,17 @@
 /*
- *  infopanel.cpp
+ *  SPDX-FileCopyrightText: 2009 David Hubner <hubnerd@ntlworld.com>
  *
- *  Copyright (C) 2009 David Hubner <hubnerd@ntlworld.com>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
 #include "infopanel.h"
 
-//Solid
+// Solid
 #include <solid/device.h>
 
-#include <QLabel>
 #include <QIcon>
+#include <QLabel>
 
 #include "devinfo.h"
 #include "qvlistlayout.h"
@@ -40,8 +26,7 @@ InfoPanel::InfoPanel(QWidget *parent, DevInfoPlugin *stat)
     setDefaultText();
     adjustSize();
 
-    setWhatsThis(i18nc("Info Panel Whats This",
-                       "Shows information about the currently selected device."));
+    setWhatsThis(i18nc("Info Panel Whats This", "Shows information about the currently selected device."));
 }
 
 InfoPanel::~InfoPanel()
@@ -131,11 +116,12 @@ void InfoPanel::setTopInfo(const QIcon &deviceIcon, Solid::Device *device)
 
     tLayout->addWidget(setDevicesIcon(deviceIcon), 0, Qt::AlignHCenter);
 
-    const QStringList labels {
-        i18n("Description: "), device->description(),
-        i18n("Product: "), device->product(),
-        i18n("Vendor: "), friendlyString(device->vendor())
-    };
+    const QStringList labels{i18n("Description: "),
+                             device->description(),
+                             i18n("Product: "),
+                             device->product(),
+                             i18n("Vendor: "),
+                             friendlyString(device->vendor())};
 
     status->updateStatus(device->udi());
     tLayout->applyQListToLayout(labels);
